IsoCountry

Enum IsoCountry 

pub enum IsoCountry {
Show 15 variants US, GB, AU, DE, AT, CH, CN, TW, PT, BR, JP, ES, FR, CA, Other(Atom),
}
Countries for use Lang::Iso dialects.

These countries are used to do dialect fallback. Countries not used in that can be represented as IsoCountry::Other. If a country is in the list, you don’t need to allocate to refer to it, so there are some non-participating countries in the list simply because it’s faster.

Variants



US

United States



GB

Great Britain



AU

Australia



DE

Deutschland



AT

Austria



CH

Switzerland



CN

China



TW

Taiwan



PT

Portugal



BR

Brazil



JP

Japan



ES

Spain



FR

France



CA

Canada



Other(Atom)