pub struct IndependentDate {
pub variable: DateVariable,
pub date_parts: Vec<DatePart>,
pub delimiter: Delimiter,
pub affixes: Affixes,
pub formatting: Option<Formatting>,
pub display: Option<DisplayMode>,
pub text_case: TextCase,
}Expand description
A date element that fully defines its own output. It is ‘independent’ of any localization.
Fields
variable: DateVariabledate_parts: Vec<DatePart>delimiter: Delimiteraffixes: Affixesformatting: Option<Formatting>display: Option<DisplayMode>text_case: TextCaseTrait Implementations
Sourceimpl Clone for IndependentDate
impl Clone for IndependentDate
Sourcefn clone(&self) -> IndependentDate
fn clone(&self) -> IndependentDate
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IndependentDate
impl Debug for IndependentDate
impl Eq for IndependentDate
Sourceimpl PartialEq for IndependentDate
impl PartialEq for IndependentDate
Sourcefn eq(&self, other: &IndependentDate) -> bool
fn eq(&self, other: &IndependentDate) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for IndependentDate